#include "config.h"

#include <stdio.h>
#include <assert.h>

#include "types.h"
#include "error.h"
#include "fd.h"
#include "io.h"
#include "display.h"
#include "args.h"

/*
#define PRINT_DEBUG
#define PRINT_ERRORS
*/

#ifdef PRINT_DEBUG
void print(void)
{
	fprintf(stderr, "d.start_time == %llu\n", (unsigned long long)d.start_time);
	fprintf(stderr, "d.total_time == %llu\n", (unsigned long long)d.total_time);
	fprintf(stderr, "d.current_time == %llu\n", (unsigned long long)d.current_time);
	fprintf(stderr, "d.elapsed_time == %llu\n", (unsigned long long)d.elapsed_time);
	fprintf(stderr, "d.percent_complete == %d\n", (int)d.percent_complete);
	fprintf(stderr, "d.display_interval == %d\n", d.display_interval);
	fprintf(stderr, "d.overtime_flag == %d\n", d.overtime_flag);
	fprintf(stderr, "d.k == %d\n", d.k);
	fprintf(stderr, "d.twiddle == %d\n", d.twiddle);
	fprintf(stderr, "d.screen_width == %d\n", d.screen_width);
	fprintf(stderr, "d.manual_width == %d\n", d.manual_width);
	fprintf(stderr, "d.display_twiddle == %d\n", d.display_twiddle);
	fprintf(stderr, "d.display_datacount == %d\n", d.display_datacount);
	fprintf(stderr, "d.display_throughput == %d\n", d.display_throughput);
	fprintf(stderr, "d.display_time == %d\n", d.display_time);
	fprintf(stderr, "d.display_percent == %d\n", d.display_percent);
	fprintf(stderr, "d.display_bar == %d\n", d.display_bar);
	fprintf(stderr, "d.display_summary == %d\n", d.display_summary);
	fprintf(stderr, "io.in == %d\n", io.in);
	fprintf(stderr, "io.out == %d\n", io.out);
	fprintf(stderr, "io.in_ready == %d\n", io.in_ready);
	fprintf(stderr, "io.out_ready == %d\n", io.out_ready);
	fprintf(stderr, "io.eof_in == %d\n", io.eof_in);
	fprintf(stderr, "io.eof_out == %d\n", io.eof_out);
	fprintf(stderr, "io.buffer_size == %llu\n", (unsigned long long)io.buffer_size);
	fprintf(stderr, "io.buffer == %p\n", io.buffer);
	fprintf(stderr, "io.watermark == %d\n", io.watermark);
	fprintf(stderr, "io.last_read == %llu\n", (unsigned long long)io.last_read);
	fprintf(stderr, "io.last_write == %llu", (unsigned long long)io.last_write);
	fprintf(stderr, "io.total_read == %llu\n", (unsigned long long)io.total_read);
	fprintf(stderr, "io.total_write == %llu\n", (unsigned long long)io.total_write);
	fprintf(stderr, "io.total_size == %llu\n", (unsigned long long)io.total_size);
	fprintf(stderr, "io.total_size_known == %d\n", io.total_size_known);
	fprintf(stderr, "io.timeout == %llu\n", (unsigned long long)io.timeout);
}
#endif

int test_parse(FILE *out, char* s, int r, uint64 n)
{
	int result_r;
	uint64 result_n;

#ifdef PRINT_ERRORS
	if (r != 0) {
		fprintf(out, "\n");
		fprintf(out, "You should see an error message here:\n");
		fprintf(out, "---[ BEGIN ]-----------------------------------\n");
	}
#endif
	result_r = parse_num(out, s, &result_n);
#ifdef PRINT_ERRORS
	if (r != 0) {
		fprintf(out, "---[ END ]-------------------------------------\n");
	}
#endif
	if ((result_r != r) || (result_n != n)) {
#ifdef PRINT_ERRORS
		fprintf(out, "*** ERROR: Number parse test failed on: %s\n", s);
		fprintf(out, "           Expected result: %d  Got: %d\n", r, result_r);
		fprintf(out, "           Expected number: %llu\n", n);
		fprintf(out, "                Got number: %llu\n", result_n);
#endif
		return(0);
	}
	return(1);
}

void test1(FILE *out)
{
	uint64 k = 1000;
	uint64 m = k*k;

	displayInit();
	ioInit();
	d.k = k;

	assert(test_parse(out, "", 0, 0));
	assert(test_parse(out, "m", 0, 0));
	assert(test_parse(out, "1m1", 1, 0));
	assert(test_parse(out, ".m", 0, 0));
	assert(test_parse(out, ".0m", 0, 0));
	assert(test_parse(out, ".1m", 0, 0.1*m));
	assert(test_parse(out, ".10m", 0, 0.1*m));
	assert(test_parse(out, "1024.38m", 0, 1024.38*m));
	assert(test_parse(out, "1024.380m", 0, 1024.38*m));
	assert(test_parse(out, "1024.38002m", 0, 1024.38002*m));
	assert(test_parse(out, "18446744073709551615", 0, 18446744073709551615));
	assert(test_parse(out, "18446744073709551616", 1, 0));
	assert(test_parse(out, "15.9999999999k", 0, 16000));
	assert(test_parse(out, "15.9999999999999999e", 0, 15999999999999999900));
	assert(test_parse(out, "15.999999999999999999e", 0, 15999999999999999999));
	assert(test_parse(out, "18.44674407370955161e", 0, MAX_UINT64/10*10));
}

void test2(FILE *out)
{
	uint64 k = 1024;

	displayInit();
	ioInit();
	d.k = k;

	assert(test_parse(out, "", 0, 0));
	assert(test_parse(out, "m", 0, 0));
	assert(test_parse(out, "1m1", 1, 0));
	assert(test_parse(out, ".m", 0, 0));
	assert(test_parse(out, ".0m", 0, 0));
	assert(test_parse(out, ".1m", 0, 104858));
	assert(test_parse(out, ".10m", 0, 104858));
	assert(test_parse(out, "1024.38m", 0, 1074140283));
	assert(test_parse(out, "1024.380m", 0, 1074140283));
	assert(test_parse(out, "1024.38002m", 0, 1074140304));
	assert(test_parse(out, "18446744073709551615", 0, 18446744073709551615));
	assert(test_parse(out, "18446744073709551616", 1, 0));
	assert(test_parse(out, "15.9999999999k", 0, 16384));
	assert(test_parse(out, "15.9999999999999999e", 0, 18446744073709551500));
	assert(test_parse(out, "15.999999999999999999e", 0, 18446744073709551614));
	assert(test_parse(out, "15.99999999999999999913e", 0, 18446744073709551614));
}

void test3(FILE* out)
{
	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test4(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test5(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-if";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test6(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "/dev/null";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test7(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-if";
	argv[argc++] = "/dev/null";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in != 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test8(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-of";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test9(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-of";
	argv[argc++] = "/dev/null";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out != 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test10(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-s";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test11(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-s";
	argv[argc++] = "/dev/null";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test12(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-s";
	argv[argc++] = "1024.38002m";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 1074140304);
	assert(io.total_size_known == 1);
	assert(io.timeout == 250000);
}

void test13(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-bs";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test14(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-bs";
	argv[argc++] = "/dev/null";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test15(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-bs";
	argv[argc++] = "1024.38002m";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1074140304);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test16(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-i";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test17(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-i";
	argv[argc++] = "/dev/null";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test18(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-i";
	argv[argc++] = "1024.38002m";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test19(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-i";
	argv[argc++] = "1024.38002";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test20(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-i";
	argv[argc++] = "30";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 30);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test21(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-t";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test22(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-t";
	argv[argc++] = "/dev/null";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test23(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-t";
	argv[argc++] = "1024.38002m";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test24(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-t";
	argv[argc++] = "1024.38002";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test25(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-t";
	argv[argc++] = "30";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 30);
}

void test26(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-k";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test27(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-k";
	argv[argc++] = "10";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test28(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-k";
	argv[argc++] = "1000";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1000);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test29(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-k";
	argv[argc++] = "1024";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.k = 1000;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test30(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-sw";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test31(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-sw";
	argv[argc++] = "0";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test32(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-sw";
	argv[argc++] = "1";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.screen_width == 1);
	assert(d.manual_width == 1);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test33(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-dtw";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_twiddle = 0;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test34(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-ntw";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 0);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test35(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-dc";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_datacount = 0;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test36(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-nc";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 0);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test37(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-dth";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_throughput = 0;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test38(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-nth";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 0);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test39(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-dt";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_time = 0;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test40(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-nt";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 0);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test41(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-dp";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_percent = 0;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test42(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-np";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 0);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test43(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-db";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_bar = 0;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test44(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-nb";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 0);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test45(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-ds";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_summary = 0;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test46(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-ns";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test47(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-da";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_twiddle = 0;
	d.display_datacount = 0;
	d.display_throughput = 0;
	d.display_time = 0;
	d.display_percent = 0;
	d.display_bar = 0;
	d.display_summary = 0;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test48(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-dn";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 0);
	assert(d.display_datacount == 0);
	assert(d.display_throughput == 0);
	assert(d.display_time == 0);
	assert(d.display_percent == 0);
	assert(d.display_bar == 0);
	assert(d.display_summary == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test49(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--in-file";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test50(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--in-file";
	argv[argc++] = "/dev/null";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in != 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test51(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--out-file";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test52(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--out-file";
	argv[argc++] = "/dev/null";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out != 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test53(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--size";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test54(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--size";
	argv[argc++] = "/dev/null";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test55(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--size";
	argv[argc++] = "1024.38002m";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 1074140304);
	assert(io.total_size_known == 1);
	assert(io.timeout == 250000);
}

void test56(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--buffer-size";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test57(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--buffer-size";
	argv[argc++] = "/dev/null";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test58(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--buffer-size";
	argv[argc++] = "1024.38002m";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1074140304);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test59(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--interval";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test60(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--interval";
	argv[argc++] = "/dev/null";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test61(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--interval";
	argv[argc++] = "1024.38002m";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test62(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--interval";
	argv[argc++] = "1024.38002";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test63(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--interval";
	argv[argc++] = "30";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 30);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test64(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--timeout";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test65(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--timeout";
	argv[argc++] = "/dev/null";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test66(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--timeout";
	argv[argc++] = "1024.38002m";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test67(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--timeout";
	argv[argc++] = "1024.38002";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test68(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--timeout";
	argv[argc++] = "30";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 30);
}

void test69(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--kilo";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test70(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--kilo";
	argv[argc++] = "10";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test71(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--kilo";
	argv[argc++] = "1000";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1000);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test72(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--kilo";
	argv[argc++] = "1024";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.k = 1000;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test73(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--screen-width";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test74(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--screen-width";
	argv[argc++] = "0";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 1);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test75(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--screen-width";
	argv[argc++] = "1";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.screen_width == 1);
	assert(d.manual_width == 1);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test76(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--display-twiddle";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_twiddle = 0;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test77(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--no-twiddle";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 0);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test78(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--display-count";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_datacount = 0;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test79(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--no-count";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 0);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test80(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--display-throughput";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_throughput = 0;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test81(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--no-throughput";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 0);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test82(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--display-time";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_time = 0;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test83(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--no-time";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 0);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test84(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--display-percent";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_percent = 0;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test85(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--no-percent";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 0);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test86(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--display-bar";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_bar = 0;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test87(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--no-bar";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 0);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test88(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--display-summary";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_summary = 0;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test89(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--no-summary";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test90(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--display-all";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	d.display_twiddle = 0;
	d.display_datacount = 0;
	d.display_throughput = 0;
	d.display_time = 0;
	d.display_percent = 0;
	d.display_bar = 0;
	d.display_summary = 0;
	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test91(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--display-none";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.display_twiddle == 0);
	assert(d.display_datacount == 0);
	assert(d.display_throughput == 0);
	assert(d.display_time == 0);
	assert(d.display_percent == 0);
	assert(d.display_bar == 0);
	assert(d.display_summary == 0);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test92(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "-sw-1";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.screen_width_minus_one == 1);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

void test93(FILE* out)
{
	int argc = 0;
	char *argv[256] = { 0 };

	argv[argc++] = "ProgramName";
	argv[argc++] = "--screen-width-minus-one";

	displayInit();
	ioInit();

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0);
	assert(d.screen_width_minus_one == 0);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);

	assert(parse_args(out, argc, argv) == 0);

#ifdef PRINT_DEBUG
	print();
#endif
	assert(d.start_time == 0);
	assert(d.total_time == 0);
	assert(d.current_time == 0);
	assert(d.elapsed_time == 0);
	assert(d.percent_complete == 0);
	assert(d.display_interval == 1);
	assert(d.overtime_flag == 0);
	assert(d.k == 1024);
	assert(d.twiddle == '-');
	assert(d.manual_width == 0); 
	assert(d.screen_width_minus_one == 1);
	assert(d.display_twiddle == 1);
	assert(d.display_datacount == 1);
	assert(d.display_throughput == 1);
	assert(d.display_time == 1);
	assert(d.display_percent == 1);
	assert(d.display_bar == 1);
	assert(d.display_summary == 1);
	assert(io.in == 0);
	assert(io.out == 1);
	assert(io.in_ready == 0);
	assert(io.out_ready == 0);
	assert(io.eof_in == 0);
	assert(io.eof_out == 0);
	assert(io.buffer_size == 1024);
	assert(io.buffer == 0x0);
	assert(io.watermark == 0);
	assert(io.last_read == 0);
	assert(io.last_write == 0);
	assert(io.total_read == 0);
	assert(io.total_write == 0);
	assert(io.total_size == 0);
	assert(io.total_size_known == 0);
	assert(io.timeout == 250000);
}

int main(int argc, char *argv[])
{
	FILE *out = stderr;

#ifndef PRINT_ERRORS
	out = fopen("/dev/null", "w");
	assert(out != 0);
#endif

	test1(out);
	test2(out);
	test3(out);
	test4(out);
	test5(out);
	test6(out);
	test7(out);
	test8(out);
	test9(out);
	test10(out);
	test11(out);
	test12(out);
	test13(out);
	test14(out);
	test15(out);
	test16(out);
	test17(out);
	test18(out);
	test19(out);
	test20(out);
	test21(out);
	test22(out);
	test23(out);
	test24(out);
	test25(out);
	test26(out);
	test27(out);
	test28(out);
	test29(out);
	test30(out);
	test31(out);
	test32(out);
	test33(out);
	test34(out);
	test35(out);
	test36(out);
	test37(out);
	test38(out);
	test39(out);
	test40(out);
	test41(out);
	test42(out);
	test43(out);
	test44(out);
	test45(out);
	test46(out);
	test47(out);
	test48(out);
	test49(out);
	test50(out);
	test51(out);
	test52(out);
	test53(out);
	test54(out);
	test55(out);
	test56(out);
	test57(out);
	test58(out);
	test59(out);
	test60(out);
	test61(out);
	test62(out);
	test63(out);
	test64(out);
	test65(out);
	test66(out);
	test67(out);
	test68(out);
	test69(out);
	test70(out);
	test71(out);
	test72(out);
	test73(out);
	test74(out);
	test75(out);
	test76(out);
	test77(out);
	test78(out);
	test79(out);
	test80(out);
	test81(out);
	test82(out);
	test83(out);
	test84(out);
	test85(out);
	test86(out);
	test87(out);
	test88(out);
	test89(out);
	test90(out);
	test91(out);
	test92(out);
	test93(out);

#ifdef PRINT_ERRORS
	fclose(out);
#endif
	return(0);
}

